Calculate Food Security Sectoral Composite Score and Need Indicators
Source:R/add_comp_foodsec.R
add_comp_foodsec.RdThis function calculates a food security sectoral composite score based on the FCLCM phase. It assigns a score from 1 to 5 corresponding to the FCLCM phase, and determines if a household is in need or in severe need of food security assistance.
Prerequisite food security functions must be run before this function:
add_fcs()
add_hhs()
add_rcsi()
add_lcsi()
add_fclcm_phase()
Usage
add_comp_foodsec(
df,
fclcm_phase = "fclcm_phase",
phase1 = "Phase 1 FCLC",
phase2 = "Phase 2 FCLC",
phase3 = "Phase 3 FCLC",
phase4 = "Phase 4 FCLC",
phase5 = "Phase 5 FCLC"
)